pragma Style_Checks (Off);

with stddef_h;
with System;

package dbus_memory_h is

   --  arg-macro: function dbus_new (type, count)
   --    return (type*)dbus_malloc (sizeof (type) * (count));
   --  arg-macro: function dbus_new0 (type, count)
   --    return (type*)dbus_malloc0 (sizeof (type) * (count));
   function dbus_malloc (bytes : stddef_h.size_t) return System.Address;  -- /usr/include/dbus-1.0/dbus/dbus-memory.h:43
   pragma Import (C, dbus_malloc, "dbus_malloc");

   function dbus_malloc0 (bytes : stddef_h.size_t) return System.Address;  -- /usr/include/dbus-1.0/dbus/dbus-memory.h:48
   pragma Import (C, dbus_malloc0, "dbus_malloc0");

   function dbus_realloc (memory : System.Address; bytes : stddef_h.size_t) return System.Address;  -- /usr/include/dbus-1.0/dbus/dbus-memory.h:53
   pragma Import (C, dbus_realloc, "dbus_realloc");

   procedure dbus_free (memory : System.Address);  -- /usr/include/dbus-1.0/dbus/dbus-memory.h:56
   pragma Import (C, dbus_free, "dbus_free");

   procedure dbus_free_string_array (str_array : System.Address);  -- /usr/include/dbus-1.0/dbus/dbus-memory.h:62
   pragma Import (C, dbus_free_string_array, "dbus_free_string_array");

   type DBusFreeFunction is access procedure (arg1 : System.Address);
   pragma Convention (C, DBusFreeFunction);  -- /usr/include/dbus-1.0/dbus/dbus-memory.h:64

   procedure dbus_shutdown;  -- /usr/include/dbus-1.0/dbus/dbus-memory.h:67
   pragma Import (C, dbus_shutdown, "dbus_shutdown");

end dbus_memory_h;
